bayespy.inference.vmp.transformations.RotateGaussianARD.bound
=============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianARD.bound